@@ -287,7 +287,9 @@ def sampler_page():
         # Tests background image, Button, RoundedButton, DynamicButton,
         # ToggleButton, ButtonGroup, Label, Indicator, ...
         [
-            _up_button, _up_dn_indicator, _dn_button,
+            # Putting a non-focus element first to test that case in
+            # keyboard control
+            _up_dn_indicator, _up_button, _dn_button,
             _back_button, _do_nothing_button, _next_button,
             _boop_button, _boop_indicator,
 
